

# zetup.py



[![](https://pypip.in/v/zetup/badge.svg)](
  https://pypi.python.org/pypi/zetup)
[![](https://travis-ci.org/userzimmermann/zetup.py.svg?branch=master)](
  https://travis-ci.org/userzimmermann/zetup.py)



## Zimmermann's [Python](http://python.org) package setup



<https://bitbucket.org/userzimmermann/zetup.py>

<https://github.com/userzimmermann/zetup.py>

